HEI Planning System
===================

Tools and data structures for HEI planning with respect to: 

- Finance
- Curriculum
- Timetabling
- Space

Please use the project [documentation](https://hei-planning-system.readthedocs.io/en/latest/) 
for more information. 